@@ -18,15 +18,13 @@ class Neo4j:
     """
     Neo4j类用于连接执行neo4j相关命令
     """
-    def __init__(self, ip, port, user, password):
+    def __init__(self, url, user, password):
         """__init__(self):方法用于
 
         Parameters
         ----------
-        ip : str
+        url : str
             neo4j服务器地址
-        port : str or int
-            端口号
         user : str
             用户名
         password : str
@@ -34,7 +32,7 @@ class Neo4j:
         Returns
         ----------
         """
-        self._driver = GraphDatabase.driver(f"neo4j://{ip}:{port}", auth=(user, password))
+        self._driver = GraphDatabase.driver(url, auth=(user, password))
 
     def close(self):
         """close方法用于关闭连接
@@ -85,7 +83,7 @@ class Neo4j:
         """
         result = None
         with self._driver.session() as session:
-            if 'return' in cypher or 'RETURN' in cypher:
+            if ' return ' in cypher or ' RETURN ' in cypher:
                 result = session.read_transaction(self._cypher_run, cypher=cypher, rtype=rtype)  # 查询操作
             else:
                 session.write_transaction(self._cypher_run, cypher=cypher, rtype=rtype)  # 写操作
@@ -102,6 +100,6 @@ def get_help():
     print("password = 'neo4j'")
     print("db = neo4j.Neo4j(ip, port, user, password)")
     print("""cmd = match (p) where id(p)=1 return p""")
-    print("result = db.run(cmd, rtype='data') #rtype='data' or 'graph' or None ")
+    print("result = db.run(cmd, rtype='data') # rtype='data' or 'graph' or None ")
     print("db.close()")
 
